<?php
/*
Plugin Name: WordPressLAB Sidebar Menu
Plugin URI: http://www.wordpresslab.co.kr
Description: 포스트 및 페이지, 카테고리별 메뉴 출력
Version: 0.5
Author: DK Kim
Author URI: http://www.wordpresslab.co.kr
License: GPL2
*/

add_action('admin_menu','wordpresslab_sidebar_menu_metabox');

$sidebar_meta_box = array(
        'id' => 'sidebar-menu-meta-box',
        'title' => 'Sidebar Menu',
        'page' => array('post', 'page'),
        'context' => 'side',
        'priority' => 'high',
        'fields' => array(
                array(
                        'name' => __("메뉴", 'wordpresslab'),
                        'desc' => __("사이드바 메뉴 선택", 'wordpresslab'),
                        'id' => 'sidebar_menu',
                        'type' => 'sidebar_menu',
                        'std' => ''
                )
        )
);

function wordpresslab_sidebar_menu_metabox() {
    global $sidebar_meta_box, $post;
    
    foreach($sidebar_meta_box['page'] as $row) {
        add_meta_box($sidebar_meta_box['id'], $sidebar_meta_box['title'], 'sidebar_meta_box', $row, $sidebar_meta_box['context'], $sidebar_meta_box['priority']);
    }

}

function sidebar_meta_box() {
    global $sidebar_meta_box, $post;
    
    $jquery = '';

    // Use nonce for verification
    echo '<input type="hidden" name="sidebar_meta_box_nonce" value="', wp_create_nonce(basename(__FILE__)), '" />';

    echo '<table class="form-table">';

    foreach ($sidebar_meta_box['fields'] as $field) {
        // get current post meta data
        $meta = get_post_meta($post->ID, $field['id'], true);

        echo '<tr>'.
            '<th style="width:40px;"><label for="'.$field['id'].'">'.$field['name'].'</label></th>'.
            '<td>';
        
        switch ($field['type']) {
            case 'sidebar_menu':
                $taxonomies = get_terms('nav_menu', array('hide_empty'=>false));
                if($taxonomies) {
                    echo '<select name="'.$field['id'].'" id="'.$field['id'].'">'."\n";
                    echo '<option value=""></option>'."\n";
                    foreach($taxonomies as $taxonomy) {
                        if($taxonomy->name == $meta)
                            echo '<option value="'.$taxonomy->name.'" selected>'.$taxonomy->name.'</option>'."\n";
                        else
                            echo '<option value="'.$taxonomy->name.'">'.$taxonomy->name.'</option>'."\n";
                    }
                    echo '</select>'."\n";
                }
                break;
        }
        echo '<td>'.
            '</tr>';
    }

    echo '</table>';
}

add_action('save_post', 'sidebar_save_data');

// Save data from meta box
function sidebar_save_data($post_id) {
    global $sidebar_meta_box;

    // verify nonce
    if (!wp_verify_nonce($_POST['sidebar_meta_box_nonce'], basename(__FILE__))) {
        return $post_id;
    }

    // check autosave
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }

    // check permissions
    if ('page' == $_POST['post_type']) {
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }
    } elseif (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }

    foreach ($sidebar_meta_box['fields'] as $field) {
        $old = get_post_meta($post_id, $field['id'], true);
        $new = $_POST[$field['id']];

        if ($new && $new != $old) {
            update_post_meta($post_id, $field['id'], $new);
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id, $field['id'], $old);
        }
    }
}

// 위젯, 사이드바 메뉴 추가 위젯
class WordpressLab_Sidebar_Menu extends WP_Widget {
    public function __construct() {
        $widget_opts = array(
                'classname'=>'wordpresslab_wsm_widget',
                'description'=>'포스트나 페이지에 따라서 메뉴 출력'
                );
        parent::__construct('wordpresslab_wsm_widget', 'Sidebar Menu', $widget_opts);
    }

    public function form($instance) {
        if(isset($instance[title])) {
            $title = $instance[title];
        } else {
            $title = '';
        }
?>
        <p>
            <label for="<?php $this->get_field_id('title');?>"><?php _e('Title:');?></label>
            <input class="widefat" id="<?php echo $this->get_field_id('title');?>" name="<?php echo $this->get_field_name('title');?>" type="text" value="<?php echo esc_attr($title);?>" />
        </p>
<?php
    }
    
    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance[title] = strip_tags($new_instance[title]);
        
        return $instance;
    }
    
    public function widget($args, $instance) {
        global $post;

        if(is_singular()) {
            $nav_menu = get_post_meta($post->ID, 'sidebar_menu', true);
            
            //echo 'nav menu: '.$nav_menu;
            $categories = get_the_category();
            //print_r($categories);

            if($nav_menu != null) {
                extract($args);
                $title = apply_filters('widget_title', $instance['title']);

                echo $before_widget;

                if(!empty($title)) {
                    echo $before_title.$title.$after_title;
                }

                //메뉴 헤드 디자인시 사용
                //include_once $nav_menu.'.php';

                wp_nav_menu( array('menu' => $nav_menu ) );

                echo $after_widget;
            }
        }
    }
}

add_action('widgets_init', create_function('','register_widget("WordpressLab_Sidebar_Menu");'));
